@@ -73,7 +73,7 @@ def configuration():
   res += "</table><div align='right'><small>%s</small></div>" % time.strftime(
       '%a %b %d %H:%M:%S %Y %Z')
 
-  return IPython.display.HTML(res)
+  display(HTML(res))
 
 
 def _reprGraph(gr, size, format, asString):
@@ -144,7 +144,9 @@ def getDot(dotstring, size="4", format="png"):
   :param format: render as "png" or "svg"
   :return: the HTML representation of the graph
   """
-  return getGraph(dot.graph_from_dot_data(dotstring), size, format)
+  g=dot.graph_from_dot_data(dotstring)
+  g.set_bgcolor("transparent")
+  return getGraph(g, size, format)
 
 
 def showJunctionTree(bn, withNames=True, size="4", format="png"):
@@ -451,15 +453,10 @@ def _reprPotential(pot, digits=4, withColors=True, varnames=None, asString=False
 
 
   :param pot: the potential to get
-  :type pot: gum.Potential
   :param digits: number of digits to show
-  :type digits: int
   :param: withColors : bgcolor for proba cells or not
-  :type withColors: boolean
   :param varnames: the aliases for variables name in the table
-  :type varnames: list of strings
   :param asString: display the table or a HTML string
-  :type asString: boolean
   :return: the representation
   """
   from IPython.core.display import HTML
@@ -552,18 +549,13 @@ def showPotential(pot, digits=4, withColors=True, varnames=None):
   show a gum.Potential as a HTML table.
   The first dimension is special (horizontal) due to the representation of conditional probability table
 
-
-  :param pot: the potential to get
-  :type pot: gum.Potential
-  :param digits: number of digits to show
-  :type digits: int
-  :param: withColors : bgcolor for proba cells or not
-  :type withColors: boolean
-  :param varnames: the aliases for variables name in the table
-  :type varnames: list of strings
+  :param gum.Potential pot: the potential to get
+  :param int digits: number of digits to show
+  :param: boolean withColors : bgcolor for proba cells or not
+  :param list of strings varnames: the aliases for variables name in the table
   :return: the display of the potential
   """
-  return _reprPotential(pot, digits, withColors, varnames, asString=False)
+  display(_reprPotential(pot, digits, withColors, varnames, asString=False))
 
 
 def getPotential(pot, digits=4, withColors=True, varnames=None):
@@ -571,14 +563,10 @@ def getPotential(pot, digits=4, withColors=True, varnames=None):
   return a HTML string of a gum.Potential as a HTML table.
   The first dimension is special (horizontal) due to the representation of conditional probability table
 
-  :param pot: the potential to get
-  :type pot: gum.Potential
-  :param digits: number of digits to show
-  :type digits: int
-  :param: withColors : bgcolor for proba cells or not
-  :type withColors: boolean
-  :param varnames: the aliases for variables name in the table
-  :type varnames: list of strings
+  :param gum.Potential pot: the potential to get
+  :param int digits: number of digits to show
+  :param: boolean withColors : bgcolor for proba cells or not
+  :param list of strings varnames: the aliases for variables name in the table
   :return: the HTML string
   """
   return _reprPotential(pot, digits, withColors, varnames, asString=True)
@@ -645,23 +633,24 @@ def getInferenceEngine(ie, inferenceCaption):
   """
   display an inference as a BN+ lists of hard/soft evidence and list of targets
 
-  :param ie:
+  :param gum.InferenceEngine ie: inference engine
+  :param string inferenceCaption : title for caption
   """
   t = '<div align="left"><ul>'
   if ie.nbrHardEvidence() > 0:
     t += "<li><b>hard evidence</b><br/>"
-    t += ", ".join([ie.BN().variable(n).name() for n in ie.hardEvidenceList()])
+    t += ", ".join([ie.BN().variable(n).name() for n in ie.hardEvidenceNodes()])
     t += "</li>"
   if ie.nbrSoftEvidence() > 0:
     t += "<li><b>soft evidence</b><br/>"
-    t += ", ".join([ie.BN().variable(n).name() for n in ie.softEvidenceList()])
+    t += ", ".join([ie.BN().variable(n).name() for n in ie.softEvidenceNodes()])
     t += "</li>"
   if ie.nbrTargets() > 0:
     t += "<li><b>target(s)</b><br/>"
     if ie.nbrTargets() == ie.BN().size():
       t += " all"
     else:
-      t += ", ".join([ie.BN().variable(n).name() for n in ie.targetList()])
+      t += ", ".join([ie.BN().variable(n).name() for n in ie.targets()])
     t += "</li>"
 
   if hasattr(ie, 'nbrJointTargets'):
@@ -678,6 +667,12 @@ def getInferenceEngine(ie, inferenceCaption):
 # adding _repr_html_ to some pyAgrum classes !
 gum.BayesNet._repr_html_ = lambda self: getBN(self)
 gum.Potential._repr_html_ = lambda self: getPotential(self)
+gum.LazyPropagation._repr_html_ = lambda self: getInferenceEngine(self, "Lazy Propagation on this BN")
+
+gum.UndiGraph._repr_html_ = lambda self: getDot(self.toDot())
+gum.DiGraph._repr_html_ = lambda self: getDot(self.toDot())
+gum.MixedGraph._repr_html_ = lambda self: getDot(self.toDot())
 gum.DAG._repr_html_ = lambda self: getDot(self.toDot())
 gum.CliqueGraph._repr_html_ = lambda self: getDot(self.toDot())
-gum.LazyPropagation._repr_html_ = lambda self: getInferenceEngine(self, "Lazy Propagation on this BN")
+gum.EssentialGraph._repr_html_ = lambda self: getDot(self.toDot())
+gum.MarkovBlanket._repr_html_ = lambda self: getDot(self.toDot())
